function U = HT1D_FEM_SS11(x,t,k,rho,cp,u0,uL,uR,qL,qR,s,theta)

nnod = length(x);
ntime = length(t);
dx = x(2)-x(1);
dt = t(2)-t(1);

if theta < 0.5
    dt_cr = 2/(1-2*theta)/3/k*rho*cp*dx^2;
    if  dt > dt_cr
        warning('Time increment (%f) should be less than critical value (%f)',dt,dt_cr);
    end
end

M = FEM_mat_1D(x,0,0);
C = rho*cp*FEM_mat_1D(x,0,0);
K = k*FEM_mat_1D(x,1,1);

G = C + theta*dt*K;
fnew = M*s(:,1) + [qL(1) zeros(1,nnod-2) qR(1)]';
mask_d = ones(nnod,1);
aux_b = zeros(nnod,ntime);
if ~isempty(uL)
    G(1,:) = eye(1,nnod);
    mask_d(1) = 0;
    aux_b(1,:) = uL(:)';
end
if ~isempty(uR)
    G(end,:) = fliplr(eye(1,nnod));
    mask_d(end) = 0;
    aux_b(end,:) = uR(:)';
end

U = zeros(nnod,ntime);
U(:,1) = u0;

for i=2:ntime
    fold = fnew;
    fnew = M*s(:,i) + [qL(i) zeros(1,nnod-2) qR(i)]';
    f = fold + theta*(fnew-fold);
    b = (C-(1-theta)*dt*K)*U(:,i-1) + dt*f;
    b = b.*mask_d + aux_b(:,i);
    Unew = G\b;
    U(:,i) = Unew;
end
end