
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SCHOOL ON MODEL ORDER REDUCTION
% UKACM CONFERENCE, 2021
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

close all
clear all

%%%%%%%%%%%%%%%%%%%%%%%%%%%%% DATA ENTRY %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% BAR LENGTH AND TIME INTERVAL
L = 1; T = 1;

% MATERIAL PROPERTIES (diffusivity, mass density, specific heat)
k = 1; rho = 1; cp = 1; 

% ELEMENT DIMENSION, TIME INCREMENT
dx = 0.04; dt = 0.01; 

% TIME INTEGRATION PARAMETER FROM 0 (FULLY EXPLICIT) TO 1 (FULLY IMPLICIT)
theta = 0.5;

% INITIAL CONDITION 
f_u0 = @(aux) zeros(length(aux),1);
%f_u0 = @(aux) sin(pi*aux);

% DIRICHLET BC (L: left, R: right)
f_uL = @(aux) zeros(length(aux),1);
f_uR = @(aux) zeros(length(aux),1);
% f_uL = @(aux) [];
% f_uR = @(aux) [];

% NEWMANN BC (L: left, R: right)
f_qL = @(aux) zeros(length(aux),1);
f_qR = @(aux) zeros(length(aux),1);
%f_qR = @(aux) sin(pi*aux/T/2);

% HEAT SOURCE
f_s = @(auxx,auxt) ones(length(auxx),length(auxt));
%f_s = @(auxx,auxt) zeros(length(auxx),length(auxt));
% f_s = @(auxx,auxt) sin(pi*auxx/2/L)*ones(1,length(auxt));


%%%%%%%%%%%%%%% PREVIOUS COMPUTATIONS AND VERIFICATIONS %%%%%%%%%%%%%%%%%%%

x = linspace(0,L,L/dx+1)';
t = linspace(0,T,T/dt+1)';
u0 = f_u0(x);
uL = f_uL(t);
uR = f_uR(t);
qL = f_qL(t);
qR = f_qR(t);
s = f_s(x,t);

% SOME VERIFICATIONS
nnod = length(x);
ntime = length(t);
if length(u0)~=nnod
    error('Bad definition of function f_u0')
elseif size(s,1)~=nnod
    error('Bad definition of function f_s')
elseif length(uL)~=ntime && ~isempty(uL)
    error('Bad definition of function f_uL')
elseif length(uR)~=ntime && ~isempty(uR)
    error('Bad definition of function f_uR')
elseif length(qL)~=ntime
    error('Bad definition of function f_qL')
elseif length(qR)~=ntime
    error('Bad definition of function f_qR')
end


%%%%%%%%%%%%%%%%%%%%%%%%%% NON REDUCED MODEL %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% SOLVE: LINEAR FINITE ELEMENTS & SINGLE STEP 1st ORDER TIME INTEGRATION
uFEM = HT1D_FEM_SS11(x,t,k,rho,cp,u0,uL,uR,qL,qR,s,theta);


%%%%%%%%%%%%%%%%%%%%%%%%%% POD REDUCED MODEL %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% SET 1 TO COMPUTE NEW POD BASIS. SET 0 TO USE PREVIOUS ONE
newpod = 1;

% NUMBER OF SNAPSHOTS
nsnap = 26;

% POD THRESHOLD
threshold = 1.e-6;

% POD COMPUTATION
mPOD = pod(uFEM,x,t,k,rho,cp,u0,qL,qR,s,theta,newpod,nsnap,threshold);
save('plotPOD','x','t','uFEM','mPOD')

return

