function mPOD = pod(uFEM,x,t,k,rho,cp,u0,qL,qR,s,theta,newpod,nsnap,threshold)

% USE PRECOMPUTED REDUCED BASIS OR COMPUTE NEW ONE
if newpod==0 && exist('POD_RB.mat','file')==2
    load('POD_RB.mat')
else
    % TAKE SNAPSHOTS IN TIME
    if nsnap > length(t)
        error('Number of snapshots (%d) must not be greater than total time points (%d)',nsnap,length(t))
    end
    mask = fix(linspace(1,length(t),nsnap));
    uSNP = uFEM(:,mask);
    % SINGULAR VALUE DECOMPOSITION
%    [EIGvec,EIGval,~] = svd(uSNP);
    [EIGvec,EIGval] = svd(uSNP);
    EIGval = diag(EIGval);
    weight = EIGval/sum(EIGval);
    % REDUCED BASIS. ONLY EIGVECTORS FROM EIGENVALUES GREATER THAN THRESHOLD
    RBx = EIGvec(:,weight>=threshold);
    save('POD_RB','RBx')
semilogy(weight,'*-r');
end

% RESHAPE TO ENSURE THAT X & T ARE COLUMN VECTORS
x = x(:);
t = t(:);

% SOME VARIABLES FOR CONVENIENCE
nnod = length(x);
ntime = length(t);
dt = t(2)-t(1);

% PROJECT THE FULL ORDER PROBLEM ONTO THE REDUCED BASIS
% full order matrices
M = FEM_mat_1D(x,0,0);
C = rho*cp*FEM_mat_1D(x,0,0);
K = k*FEM_mat_1D(x,1,1);
% projection
G = RBx'*C*RBx + theta*dt*RBx'*K*RBx;
fnew = RBx'*M*s(:,1) + RBx'*[qL(1) zeros(1,nnod-2) qR(1)]';

% SOLVE THE REDUCED ORDER SYSTEM OF ODE
RBt = zeros(size(RBx,2),ntime);
RBt(:,1) = RBx'*u0;
for i=2:ntime
    fold = fnew;
    fnew = RBx'*M*s(:,i) + RBx'*[qL(i) zeros(1,nnod-2) qR(i)]';
    f = fold + theta*(fnew-fold);
    b = (RBx'*C*RBx-(1-theta)*dt*RBx'*K*RBx)*RBt(:,i-1) + dt*f;
    Unew = G\b;
    RBt(:,i) = Unew;
end

% POD MODES
mPOD{1} = RBx;
mPOD{2} = RBt';